==> prestashop_1.5.0.5.zip: prestashop/install/langs/fr/install.php <==
<?php
return array(
	'informations' => array(
		'phone' => '+33 (0)1.40.18.30.04',
		'documentation' => 'http://doc.prestashop.com/pages/viewpage.action?pageId=2424836',
	),
	'translations' => array(
		'menu_welcome' => 'Bienvenue !',
		'menu_system' => 'Compatibilité système',
		'menu_database' => 'Configuration système',
		'menu_configure' => 'Configuration de la boutique',
		'menu_process' => 'Installation',
		'Choose the installer language:' => 'Choisissez votre langue pour l\'installation',
		'Field required' => 'Champ requis',
		'Invalid shop name' => 'Nom de la boutique non valide',
		'Your firstname contains some invalid characters' => 'Votre prénom contient des caractères invalides',
		'Your lastname contains some invalid characters' => 'Votre nom contient des caractères invalides',
		'The password is incorrect (alphanumeric string with at least 8 characters)' => 'Le mot de passe est invalide (caractères alpha numériques et au moins 8 lettres)',
		'Password and its confirmation are different' => 'Le mot de passe de confirmation est différent de l\'original',
		'This e-mail address is invalid' => 'Cette adresse e-mail est invalide',
		'The uploaded file exceeds the upload_max_filesize directive in php.ini' => 'La taille fichier uploadé dépasse la directive upload_max_filesize de votre php.ini',
		'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form' => 'La taille fichier uploadé dépasse la directive MAX_FILE_SIZE de votre formulaire',
		'The uploaded file was only partially uploaded' => 'Le fichier a seulement été partiellement uploadé',
		'No file was uploaded' => 'Aucun fichier n\'a pu être uploadé',
		'Missing a temporary folder' => 'Dossier temporaire manquant',
		'Failed to write file to disk' => 'Impossible d\'écrire le fichier uploadé sur le disque',
		'File upload stopped by extension' => 'Ce type d\'extension est interdit par votre serveur pour le fichier uploadé',
		'No error code available' => 'Pas de code d\'erreur disponible',
		'This is not a valid image file' => 'Cette image est invalide',
		'Image type is not supported' => 'Ce type d\'image n\'est pas supporté',
		'Image folder %s is not writable' => 'Le dossier d\'images %s ne possède pas les droits d\'écriture',
		'Cannot upload the file' => 'Impossible d\'uploader le fichier',
		'Lingerie and Adult' => 'Adulte et lingerie',
		'Animals and Pets' => 'Animaux',
		'Art and Culture' => 'Culture et divertissements',
		'Babies' => 'Articles pour bébé',
		'Beauty and Personal Care' => 'Santé et beauté',
		'Cars' => 'Auto et moto',
		'Computer Hardware and Software' => 'Informatique et logiciels',
		'Download' => 'Téléchargement',
		'Fashion and accessories' => 'Vêtements et accessoires',
		'Flowers, Gifts and Crafts' => 'Fleurs et cadeaux',
		'Food and beverage' => 'Alimentation et gastronomie',
		'HiFi, Photo and Video' => 'Hifi, photo et vidéos',
		'Home and Garden' => 'Maison et jardin',
		'Home Appliances' => 'Électroménager',
		'Jewelry' => 'Bijouterie',
		'Mobile and Telecom' => 'Téléphonie et communication',
		'Services' => 'Services',
		'Shoes and accessories' => 'Chaussures et accessoires',
		'Sports and Entertainment' => 'Sports et loisirs',
		'Travel' => 'Voyage et tourisme',
		'Database is connected' => 'La base de données est connectée',
		'A test e-mail has been sent to %s' => 'Un e-mail de test a été envoyé à %s',
		'An error occurred while sending email, please verify your parameters' => 'Une erreur est survenue lors de l\'envoi de l\'e-mail, merci de vérifier vos paramètres',
		'Create settings.inc file' => 'Création du fichier settings.inc',
		'Create database tables' => 'Création des tables de la base',
		'Populate database tables' => 'Remplissage des tables de la base',
		'Configure shop informations' => 'Configuration de la boutique',
		'Install modules' => 'Installation des modules',
		'Install demonstration data' => 'Installation des produits de démo',
		'Install theme' => 'Installation du thème',
		'PHP parameters:' => 'Paramètres PHP :',
		'Is PHP 5.1.2 or later installed ?' => 'PHP 5.1.2 ou plus est installé ?',
		'Can upload files ?' => 'Upload de fichiers autorisée ?',
		'Can create new files and folders ?' => 'Création de fichiers et dossiers autorisée ?',
		'Is GD Library installed ?' => 'Librairie GD installée ?',
		'Is MySQL support is on ?' => 'MySQL est installé ?',
		'Write permissions on files:' => 'Permissions sur les fichiers / dossiers :',
		'Can open external URLs ?' => 'Ouverture des URLs externes autorisée ?',
		'Is PHP register global option off (recommended) ?' => 'Option PHP register_global désactivée (recommandé) ?',
		'Is GZIP compression activated (recommended) ?' => 'Compression GZIP activée (recommandé) ?',
		'Is Mcrypt extension available (recommended) ?' => 'Extension Mcrypt installée (recommandé) ?',
		'Is PHP magic quotes option deactivated (recommended) ?' => 'Option PHP magic_quotes désactivée (recommandé) ?',
		'Is Dom extension loaded ?' => 'Extension DOM installée ?',
		'Is PDO MySQL extension loaded ?' => 'Extension PDO MySQL installée ?',
		'Shop settings and merchant account information' => 'Informations à propos du marchand',
		'Shop name:' => 'Nom de la boutique :',
		'Main activity:' => 'Activité principale :',
		'Please choose your main activity' => 'Merci de choisir une activité',
		'Other activity...' => 'Autre activité ...',
		'This information is not required, it will only be used for statistical purposes. This information does not change anything in your store.' => 'Cette information n\'est pas obligatoire, elle sera utilisée à des fins statistiques. Cette information ne changera rien dans votre boutique.',
		'Install demo products:' => 'Installer les produits de démo :',
		'Yes' => 'Oui',
		'No' => 'Non',
		'Demo products are a good way to learn how to use PrestaShop. You should install them if you are not familiar with it.' => 'Les produits de démo sont un bon moyen pour apprendre à utiliser PrestaShop. Vous devriez les installer si vous n\'êtes pas familier avec le logiciel.',
		'Default country:' => 'Pays par défaut :',
		'Select your country' => 'Sélectionnez un pays',
		'Shop timezone:' => 'Fuseau horaire :',
		'Select your timezone' => 'Choisissez un fuseau horaire',
		'Shop logo:' => 'Logo de la boutique',
		'Recommended dimensions:' => 'Dimensions recommandées :',
		'First name:' => 'Prénom :',
		'Last name:' => 'Nom de famille :',
		'E-mail address:' => 'Adresse e-mail :',
		'Shop password:' => 'Mot de passe :',
		'Re-type to confirm:' => 'Confirmation du mot de passe :',
		'Receive this information by e-mail' => 'Recevez ces informations par e-mail',
		'Warning: You will recieve these informations only if your e-mail configuration is correct.' => 'Attention : vous ne recevrez ces informations que si votre configuration des e-mails est correcte',
		'Configure your database by filling out the following fields:' => 'Configurez la connection à votre base de données en remplissant les champs suivants :',
		'You have to create a database, help available in <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>' => 'Vous devez créer une base de données, de l\'aide est disponible dans le fichier <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>',
		'You have to create a database, help available in <a href="README.txt" target="_blank">~/install/README.txt</a>' => 'Vous devez créer une base de données, de l\'aide est disponible dans le fichier <a href="README.txt" target="_blank">~/install/README.txt</a>',
		'Database server address:' => 'Addresse du serveur de la base :',
		'If you want to use a different port, add :XX after your server address where XX is your port number.' => 'Si vous souhaitez utiliser un port différent, ajoutez :XX à l\'adresse de votre serveur, XX étant le numéro de votre port.',
		'Database name:' => 'Nom de la base :',
		'Database login:' => 'Identifiant de la base :',
		'Database password:' => 'Mot de passe de la base :',
		'Database Engine:' => 'Type de base :',
		'Tables prefix:' => 'Préfixe des tables :',
		'Drop existing tables (mode dev):' => 'Supprimer les tables (mode dev) :',
		'Verify now!' => 'Vérifier maintenant !',
		'E-mail delivery set-up' => 'Configuration de l\'envoi des e-mails',
		'Configure SMTP manually (advanced users only)' => 'Configurer le serveur SMTP (mode expert)',
		'By default, the PHP mail() function is used' => 'Par défaut la fonction PHP mail() est utilisée',
		'SMTP server address:' => 'Adresse du serveur SMTP',
		'Encryption:' => 'Cryptage :',
		'None' => 'Aucun',
		'Port:' => 'Port :',
		'Login:' => 'Identifiant :',
		'Password:' => 'Mot de passe :',
		'enter@your.email' => 'entrez@votre.email',
		'Send me a test email!' => 'Envoyez moi un e-mail de test !',
		'Next' => 'Suivant',
		'Back' => 'Précédent',
		'Official forum' => 'Forum officiel',
		'Support' => 'Support',
		'Documentation' => 'Documentation',
		'Contact us!' => 'Nous contacter !',
		'Forum' => 'Forum',
		'Blog' => 'Blog',
		'Done!' => 'Fin !',
		'An error occured during installation...' => 'Une erreur est survenue durant l\'installation',
		'You can use the links on the left column to go back to the previous steps, or restart the installation process by <a href="%s">clicking here</a>' => 'Vous pouvez utiliser les liens à gauche pour revenir aux étapes précédentes, ou redémarrer l\'installation en <a href="%s">cliquant ici</a>',
		'Your installation is finished!' => 'L\'installation est finie !',
		'You have just finished to install and configure your shop, thank you for using PrestaShop!' => 'Vous venez d’installer et de configurer votre boutique en ligne, nous vous en remercions',
		'Please remember your login information:' => 'Merci de conserver les informations de connexion suivantes :',
		'WARNING: For security purposes, you must delete the "install" folder.' => 'ATTENTION : pour plus de sécurité, merci de supprimer le dossier \'/install\'.',
		'Back Office' => 'Administration',
		'Manage your store using your Back Office. Manage your orders and customers, add modules, change themes, etc.' => 'Administrez votre boutique avec votre back office. Gérer vos commandes et vos clients, ajouter des modules, modifier votre thème, etc...',
		'Manage your store' => 'Gérez votre boutique',
		'Front Office' => 'Front Office',
		'Discover your store as your future customers will see it!' => 'Découvrez votre boutique telle que vos futurs clients la verront !',
		'Discover your store' => 'Découvrez votre boutique',
		'Required set-up. Please verify the following checklist items are true.' => 'Merci de vous assurer que chacun des paramètres ci-dessous est valide (coche verte affichée).',
		'Your configuration is valid, click next to continue!' => 'Votre configuration est valide, vous pouvez continuer l\'installation !',
		'Your configuration is invalid. Please fix the issues below:' => 'Votre configuration est invalide. Merci de corriger les problèmes ci dessous :',
		'Optional set-up' => 'Paramètres optionnels',
		'Refresh these settings' => 'Rafraichir ces informations',
		'Welcome to the PrestaShop %s Installer.' => 'Bienvenue sur l\'installation de PrestaShop %s',
		'The installation process should take only few minutes!' => 'Le processus d\'installation devrait vous prendre quelques minutes seulement !',
		'If you need help, do not hesitate to check <a href="%1$s" target="_blank">our documentation</a> or to contact our support team: %2$s' => 'Si vous avez besoin d\'aide, n\'hésitez pas à visiter <a href="%1$s" target="_blank">notre documentation</a> ou à contacter notre équipe de support : %2$s',
		'Choose the installer language:' => 'Choisissez la langue pour l\'installation :',
		'Did you know?' => 'Le saviez vous ?',
		'PrestaShop and community offers over 40 different languages for free directly accessible from your back-office in tools tab' => 'PrestaShop et sa communauté vous proposent plus de 40 langues gratuites directement accessibles depuis votre administration',
		'Licenses Agreement' => 'Contrat de licences',
		'PrestaShop core is released under the OSL 3.0 while PrestaShop modules and themes are released under the AFL 3.0.' => 'Le coeur de PrestaShop est publié sous licence OSL 3.0 tandis que les modules et thèmes sont publiés sous licence AFL 3.0.',
		'I agree to the above terms and conditions.' => 'J\'approuve les termes et conditions du contrat ci-dessus.',
		'I agree to participate in improving the solution by sending anonymous information about my configuration.' => 'J\'accepte de participer à l\'amélioration de la solution en envoyant des informations anonymes sur ma configuration',
		'If you have any questions, please visit our <a href="%1$s" target="_blank">documentation</a> and <a href="%2$s" target="_blank">community forum</a>.' => 'Si vous avez la moindre question, n\'hésitez pas à visiter notre <a href="%1$s" target="_blank">documentation</a> et notre <a href="%2$s" target="_blank">forum communautaire</a>.',
		'Test message from PrestaShop' => 'Message test de PrestaShop',
		'This is a test message, your server is now available to send email' => 'Ceci est un message de test, votre serveur d\'email fonctionne correctement.',
		'%s - Login information' => '%s - Identifiants de connection',
		'An SQL error occured for entity <i>%1$s</i>: <i>%2$s</i>' => 'Une erreur SQL est survenue pour l\'entité <i>%1$s</i> : <i>%2$s</i>',
		'Cannot create image "%1$s" for entity "%2$s"' => 'Impossible de créer l\'image "%1$s" pour l\'entité "%2$s"',
		'Cannot create image "%1$s" (bad permissions on folder "%2$s")' => 'Impossible de créer l\'image "%1$s" (mauvaises permissions sur le dossier "%2$s")',
		'Cannot create image "%s"' => 'Impossible de créer l\'image "%s"',
		'SQL error on query <i>%s</i>' => 'Erreur SQL sur la requête <i>%s</i>',
		'Server name is not valid' => 'L\'adresse du serveur est invalide',
		'You must enter a database name' => 'Vous devez choisir une base de données',
		'You must enter a database login' => 'Vous devez entrer un identifiant pour la base',
		'Tables prefix is invalid' => 'Le préfixe des tables est invalide',
		'Wrong engine chosen for MySQL' => 'Moteur pour MySQL invalide',
		'Cannot convert database data to utf-8' => 'Impossible de convertir la base en utf-8',
		'At least one table with same prefix was already found, please change your prefix or drop your database' => 'Au moins une table avec le même préfixe a été trouvée, merci de changer votre préfixe ou de supprimer vos tables existantes',
		'Database Server is not found. Please verify the login, password and server fields' => 'Impossible de se connecter au serveur de la base de données. Vérifiez vos identifiants de connection',
		'Connection to MySQL server succeeded, but database "%s" not found' => 'La connection au serveur de base de données a réussi, mais la base "%s" n\'a pas été trouvée',
		'Engine innoDB is not supported by your MySQL server, please use MyISAM' => 'Le moteur innoDB n\'est pas supporté par votre serveur SQL, merci d\'utiliser MyISAM',
		'%s file is not writable (check permissions)' => 'Le fichier %s ne peut être écrit (vérifiez vos permissions fichiers)',
		'%s folder is not writable (check permissions)' => 'Le dossier %s ne peut être écrit (vérifiez vos permissions fichiers)',
		'Cannot write settings file' => 'Impossible de générer le fichier settings',
		'Database structure file not found' => 'Le fichier de structure de base de donnée n\'a pu être trouvé',
		'Cannot create group shop' => 'Impossible de créer le groupe de boutique',
		'Cannot create shop' => 'Impossible de créer la boutique',
		'Cannot create shop URL' => 'Impossible de créer l\'URL pour la boutique',
		'File "language.xml" not found for language iso "%s"' => 'Le fichier "language.xml" n\'a pas été trouvé pour l\'iso "%s"',
		'File "language.xml" not valid for language iso "%s"' => 'Le fichier "language.xml" est invalide pour l\'iso "%s"',
		'Cannot install language "%s"' => 'Impossible d\'installer la langue "%s"',
		'Cannot create admin account' => 'Impossible de créer le compte administrateur',
		'Cannot install module "%s"' => 'Impossible d\'installer le module "%s"',
		'Fixtures class "%s" not found' => 'La classe "%s" pour les fixtures n\'a pas été trouvée',
		'"%s" must be an instane of "InstallXmlLoader"' => '"%s" doit être une instance de "InstallXmlLoader"',
	),
);

==> prestashop_1.5.0.9.zip: prestashop/install/langs/fr/install.php <==
<?php
return array(
	'informations' => array(
		'phone' => '+33 (0)1.40.18.30.04',
		'documentation' => 'http://doc.prestashop.com/pages/viewpage.action?pageId=2424836',
	),
	'translations' => array(
		'menu_welcome' => 'Bienvenue !',
		'menu_system' => 'Compatibilité système',
		'menu_database' => 'Configuration système',
		'menu_configure' => 'Configuration de la boutique',
		'menu_process' => 'Installation',
		'Choose the installer language:' => 'Choisissez votre langue pour l\'installation',
		'Field required' => 'Champ requis',
		'Invalid shop name' => 'Nom de la boutique non valide',
		'Your firstname contains some invalid characters' => 'Votre prénom contient des caractères invalides',
		'Your lastname contains some invalid characters' => 'Votre nom contient des caractères invalides',
		'The password is incorrect (alphanumeric string with at least 8 characters)' => 'Le mot de passe est invalide (caractères alpha numériques et au moins 8 lettres)',
		'Password and its confirmation are different' => 'Le mot de passe de confirmation est différent de l\'original',
		'This e-mail address is invalid' => 'Cette adresse e-mail est invalide',
		'The uploaded file exceeds the upload_max_filesize directive in php.ini' => 'La taille fichier uploadé dépasse la directive upload_max_filesize de votre php.ini',
		'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form' => 'La taille fichier uploadé dépasse la directive MAX_FILE_SIZE de votre formulaire',
		'The uploaded file was only partially uploaded' => 'Le fichier a seulement été partiellement uploadé',
		'No file was uploaded' => 'Aucun fichier n\'a pu être uploadé',
		'Missing a temporary folder' => 'Dossier temporaire manquant',
		'Failed to write file to disk' => 'Impossible d\'écrire le fichier uploadé sur le disque',
		'File upload stopped by extension' => 'Ce type d\'extension est interdit par votre serveur pour le fichier uploadé',
		'No error code available' => 'Pas de code d\'erreur disponible',
		'This is not a valid image file' => 'Cette image est invalide',
		'Image type is not supported' => 'Ce type d\'image n\'est pas supporté',
		'Image folder %s is not writable' => 'Le dossier d\'images %s ne possède pas les droits d\'écriture',
		'Cannot upload the file' => 'Impossible d\'uploader le fichier',
		'Lingerie and Adult' => 'Lingerie et adulte',
		'Animals and Pets' => 'Animaux',
		'Art and Culture' => 'Culture et divertissements',
		'Babies' => 'Articles pour bébé',
		'Beauty and Personal Care' => 'Santé et beauté',
		'Cars' => 'Auto et moto',
		'Computer Hardware and Software' => 'Informatique et logiciels',
		'Download' => 'Téléchargement',
		'Fashion and accessories' => 'Vêtements et accessoires',
		'Flowers, Gifts and Crafts' => 'Fleurs et cadeaux',
		'Food and beverage' => 'Alimentation et gastronomie',
		'HiFi, Photo and Video' => 'Hifi, photo et vidéos',
		'Home and Garden' => 'Maison et jardin',
		'Home Appliances' => 'Électroménager',
		'Jewelry' => 'Bijouterie',
		'Mobile and Telecom' => 'Téléphonie et communication',
		'Services' => 'Services',
		'Shoes and accessories' => 'Chaussures et accessoires',
		'Sports and Entertainment' => 'Sports et loisirs',
		'Travel' => 'Voyage et tourisme',
		'Database is connected' => 'La base de données est connectée',
		'A test e-mail has been sent to %s' => 'Un e-mail de test a été envoyé à %s',
		'An error occurred while sending email, please verify your parameters' => 'Une erreur est survenue lors de l\'envoi de l\'e-mail, merci de vérifier vos paramètres',
		'Create settings.inc file' => 'Création du fichier settings.inc',
		'Create database tables' => 'Création des tables de la base',
		'Create default shop and languages' => 'Création de la boutique par défaut et des langues',
		'Populate database tables' => 'Remplissage des tables de la base',
		'Configure shop information' => 'Configuration de la boutique',
		'Install modules' => 'Installation des modules',
		'Install demonstration data' => 'Installation des produits de démo',
		'Install theme' => 'Installation du thème',
		'Send information e-mail' => 'Envoi des informations par e-mail',
		'PHP parameters:' => 'Paramètres PHP :',
		'Is PHP 5.1.2 or later installed ?' => 'PHP 5.1.2 ou plus est installé ?',
		'Can upload files ?' => 'Upload de fichiers autorisée ?',
		'Can create new files and folders ?' => 'Création de fichiers et dossiers autorisée ?',
		'Is GD Library installed ?' => 'Librairie GD installée ?',
		'Is MySQL support is on ?' => 'MySQL est installé ?',
		'Write permissions on files:' => 'Permissions sur les fichiers / dossiers :',
		'Can open external URLs ?' => 'Ouverture des URLs externes autorisée ?',
		'Is PHP register global option off (recommended) ?' => 'Option PHP register_global désactivée (recommandé) ?',
		'Is GZIP compression activated (recommended) ?' => 'Compression GZIP activée (recommandé) ?',
		'Is Mcrypt extension available (recommended) ?' => 'Extension Mcrypt installée (recommandé) ?',
		'Is PHP magic quotes option deactivated (recommended) ?' => 'Option PHP magic_quotes désactivée (recommandé) ?',
		'Is Dom extension loaded ?' => 'Extension DOM installée ?',
		'Is PDO MySQL extension loaded ?' => 'Extension PDO MySQL installée ?',
		'Shop settings and merchant account information' => 'Informations à propos du marchand',
		'Shop name:' => 'Nom de la boutique :',
		'Main activity:' => 'Activité principale :',
		'Please choose your main activity' => 'Merci de choisir une activité',
		'Other activity...' => 'Autre activité ...',
		'This information is not required, it will only be used for statistical purposes. This information does not change anything in your store.' => 'Cette information n\'est pas obligatoire, elle sera utilisée à des fins statistiques. Cette information ne changera rien dans votre boutique.',
		'Install demo products:' => 'Installer les produits de démo :',
		'Yes' => 'Oui',
		'No' => 'Non',
		'Demo products are a good way to learn how to use PrestaShop. You should install them if you are not familiar with it.' => 'Les produits de démo sont un bon moyen pour apprendre à utiliser PrestaShop. Vous devriez les installer si vous n\'êtes pas familier avec le logiciel.',
		'Default country:' => 'Pays par défaut :',
		'Select your country' => 'Sélectionnez un pays',
		'Shop timezone:' => 'Fuseau horaire :',
		'Select your timezone' => 'Choisissez un fuseau horaire',
		'Shop logo:' => 'Logo de la boutique',
		'Recommended dimensions:' => 'Dimensions recommandées :',
		'First name:' => 'Prénom :',
		'Last name:' => 'Nom de famille :',
		'E-mail address:' => 'Adresse e-mail :',
		'Shop password:' => 'Mot de passe :',
		'Re-type to confirm:' => 'Confirmation du mot de passe :',
		'Receive this information by e-mail' => 'Recevez ces informations par e-mail',
		'Warning: You will recieve these informations only if your e-mail configuration is correct.' => 'Attention : vous ne recevrez ces informations que si votre configuration des e-mails est correcte',
		'Configure your database by filling out the following fields:' => 'Configurez la connection à votre base de données en remplissant les champs suivants :',
		'You have to create a database, help available in <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>' => 'Vous devez créer une base de données, de l\'aide est disponible dans le fichier <a href="langs/%1$s/README.txt" target="_blank">~/install/langs/%1$s/README.txt</a>',
		'You have to create a database, help available in <a href="README.txt" target="_blank">~/install/README.txt</a>' => 'Vous devez créer une base de données, de l\'aide est disponible dans le fichier <a href="README.txt" target="_blank">~/install/README.txt</a>',
		'Database server address:' => 'Adresse du serveur de la base :',
		'If you want to use a different port, add :XX after your server address where XX is your port number.' => 'Si vous souhaitez utiliser un port différent, ajoutez :XX à l\'adresse de votre serveur, XX étant le numéro de votre port.',
		'Database name:' => 'Nom de la base :',
		'Database login:' => 'Identifiant de la base :',
		'Database password:' => 'Mot de passe de la base :',
		'Database Engine:' => 'Type de base :',
		'Tables prefix:' => 'Préfixe des tables :',
		'Drop existing tables (mode dev):' => 'Supprimer les tables (mode dev) :',
		'Verify now!' => 'Vérifier maintenant !',
		'E-mail delivery set-up' => 'Configuration de l\'envoi des e-mails',
		'Configure SMTP manually (advanced users only)' => 'Configurer le serveur SMTP (mode expert)',
		'By default, the PHP mail() function is used' => 'Par défaut la fonction PHP mail() est utilisée',
		'SMTP server address:' => 'Adresse du serveur SMTP',
		'Encryption:' => 'Cryptage :',
		'None' => 'Aucun',
		'Port:' => 'Port :',
		'Login:' => 'Identifiant :',
		'Password:' => 'Mot de passe :',
		'enter@your.email' => 'entrez@votre.email',
		'Send me a test email!' => 'Envoyez moi un e-mail de test !',
		'Next' => 'Suivant',
		'Back' => 'Précédent',
		'Official forum' => 'Forum officiel',
		'Support' => 'Support',
		'Documentation' => 'Documentation',
		'Contact us!' => 'Nous contacter !',
		'Forum' => 'Forum',
		'Blog' => 'Blog',
		'Done!' => 'Fin !',
		'An error occured during installation...' => 'Une erreur est survenue durant l\'installation',
		'You can use the links on the left column to go back to the previous steps, or restart the installation process by <a href="%s">clicking here</a>.' => 'Vous pouvez utiliser les liens à gauche pour revenir aux étapes précédentes, ou redémarrer l\'installation en <a href="%s">cliquant ici</a>.',
		'Your installation is finished!' => 'L\'installation est finie !',
		'You have just finished to install and configure your shop, thank you for using PrestaShop!' => 'Vous venez d’installer et de configurer votre boutique en ligne, nous vous en remercions',
		'Please remember your login information:' => 'Merci de conserver les informations de connexion suivantes :',
		'WARNING: For security purposes, you must delete the "install" folder.' => 'ATTENTION : pour plus de sécurité, merci de supprimer le dossier \'/install\'.',
		'Back Office' => 'Administration',
		'Manage your store using your Back Office. Manage your orders and customers, add modules, change themes, etc.' => 'Administrez votre boutique avec votre back office. Gérer vos commandes et vos clients, ajouter des modules, modifier votre thème, etc...',
		'Manage your store' => 'Gérez votre boutique',
		'Front Office' => 'Front Office',
		'Discover your store as your future customers will see it!' => 'Découvrez votre boutique telle que vos futurs clients la verront !',
		'Discover your store' => 'Découvrez votre boutique',
		'Required set-up. Please verify the following checklist items are true.' => 'Merci de vous assurer que chacun des paramètres ci-dessous est valide (coche verte affichée).',
		'Your configuration is valid, click next to continue!' => 'Votre configuration est valide, vous pouvez continuer l\'installation !',
		'Your configuration is invalid. Please fix the issues below:' => 'Votre configuration est invalide. Merci de corriger les problèmes ci dessous :',
		'Optional set-up' => 'Paramètres optionnels',
		'Refresh these settings' => 'Rafraîchir ces informations',
		'Welcome to the PrestaShop %s Installer.' => 'Bienvenue sur l\'installation de PrestaShop %s',
		'The installation process should take only few minutes!' => 'Le processus d\'installation devrait vous prendre quelques minutes seulement !',
		'If you need help, do not hesitate to check <a href="%1$s" target="_blank">our documentation</a> or to contact our support team: %2$s' => 'Si vous avez besoin d\'aide, n\'hésitez pas à visiter <a href="%1$s" target="_blank">notre documentation</a> ou à contacter notre équipe de support : %2$s',
		'Choose the installer language:' => 'Choisissez la langue pour l\'installation :',
		'Did you know?' => 'Le saviez vous ?',
		'PrestaShop and community offers over 40 different languages for free directly accessible from your back-office in tools tab' => 'PrestaShop et sa communauté vous proposent plus de 40 langues gratuites directement accessibles depuis votre administration',
		'Licenses Agreement' => 'Contrat de licences',
		'PrestaShop core is released under the OSL 3.0 while PrestaShop modules and themes are released under the AFL 3.0.' => 'Le cœur de PrestaShop est publié sous licence OSL 3.0 tandis que les modules et thèmes sont publiés sous licence AFL 3.0.',
		'I agree to the above terms and conditions.' => 'J\'approuve les termes et conditions du contrat ci-dessus.',
		'I agree to participate in improving the solution by sending anonymous information about my configuration.' => 'J\'accepte de participer à l\'amélioration de la solution en envoyant des informations anonymes sur ma configuration',
		'If you have any questions, please visit our <a href="%1$s" target="_blank">documentation</a> and <a href="%2$s" target="_blank">community forum</a>.' => 'Si vous avez la moindre question, n\'hésitez pas à visiter notre <a href="%1$s" target="_blank">documentation</a> et notre <a href="%2$s" target="_blank">forum communautaire</a>.',
		'Test message from PrestaShop' => 'Message test de PrestaShop',
		'This is a test message, your server is now available to send email' => 'Ceci est un message de test, votre serveur d\'email fonctionne correctement.',
		'%s - Login information' => '%s - Identifiants de connexion',
		'An SQL error occured for entity <i>%1$s</i>: <i>%2$s</i>' => 'Une erreur SQL est survenue pour l\'entité <i>%1$s</i> : <i>%2$s</i>',
		'Cannot create image "%1$s" for entity "%2$s"' => 'Impossible de créer l\'image "%1$s" pour l\'entité "%2$s"',
		'Cannot create image "%1$s" (bad permissions on folder "%2$s")' => 'Impossible de créer l\'image "%1$s" (mauvaises permissions sur le dossier "%2$s")',
		'Cannot create image "%s"' => 'Impossible de créer l\'image "%s"',
		'SQL error on query <i>%s</i>' => 'Erreur SQL sur la requête <i>%s</i>',
		'Server name is not valid' => 'L\'adresse du serveur est invalide',
		'You must enter a database name' => 'Vous devez choisir une base de données',
		'You must enter a database login' => 'Vous devez entrer un identifiant pour la base',
		'Tables prefix is invalid' => 'Le préfixe des tables est invalide',
		'Wrong engine chosen for MySQL' => 'Moteur pour MySQL invalide',
		'Cannot convert database data to utf-8' => 'Impossible de convertir la base en utf-8',
		'At least one table with same prefix was already found, please change your prefix or drop your database' => 'Au moins une table avec le même préfixe a été trouvée, merci de changer votre préfixe ou de supprimer vos tables existantes',
		'Database Server is not found. Please verify the login, password and server fields' => 'Impossible de se connecter au serveur de la base de données. Vérifiez vos identifiants de connexion',
		'Connection to MySQL server succeeded, but database "%s" not found' => 'La connection au serveur de base de données a réussi, mais la base "%s" n\'a pas été trouvée',
		'Engine innoDB is not supported by your MySQL server, please use MyISAM' => 'Le moteur innoDB n\'est pas supporté par votre serveur SQL, merci d\'utiliser MyISAM',
		'%s file is not writable (check permissions)' => 'Le fichier %s ne peut être écrit (vérifiez vos permissions fichiers)',
		'%s folder is not writable (check permissions)' => 'Le dossier %s ne peut être écrit (vérifiez vos permissions fichiers)',
		'Cannot write settings file' => 'Impossible de générer le fichier settings',
		'Database structure file not found' => 'Le fichier de structure de base de donnée n\'a pu être trouvé',
		'Cannot create group shop' => 'Impossible de créer le groupe de boutique',
		'Cannot create shop' => 'Impossible de créer la boutique',
		'Cannot create shop URL' => 'Impossible de créer l\'URL pour la boutique',
		'File "language.xml" not found for language iso "%s"' => 'Le fichier "language.xml" n\'a pas été trouvé pour l\'iso "%s"',
		'File "language.xml" not valid for language iso "%s"' => 'Le fichier "language.xml" est invalide pour l\'iso "%s"',
		'Cannot install language "%s"' => 'Impossible d\'installer la langue "%s"',
		'Cannot create admin account' => 'Impossible de créer le compte administrateur',
		'Cannot install module "%s"' => 'Impossible d\'installer le module "%s"',
		'Fixtures class "%s" not found' => 'La classe "%s" pour les fixtures n\'a pas été trouvée',
		'"%s" must be an instane of "InstallXmlLoader"' => '"%s" doit être une instance de "InstallXmlLoader"',
		'Display' => 'Afficher',
	),
);
